/* 
  SCLGlobals.m

  Barry McMullin <mcmullin@eeng.dcu.ie>
  08-OCT-1996

*/

#import "SCLGlobals.h"

id <NeighborhoodProtocol> defaultNeighbor;
id <NeighborhoodProtocol> vnNeighbor;
id <NeighborhoodProtocol> mooreNeighbor;

SCLModelSwarm *modelSwarm;

ParticleManager *holeMgr;
ParticleManager *substrateMgr;
ParticleManager *linkMgr;
ParticleManager *catalystMgr;

AgentManager *bondMgr;

PRNG *prng;

unsigned modelTime;

XColormap * colormap;
ZoomRaster * worldRaster;

Object2dDisplay * worldDisplay;

UserCellEditor * userCellEditor;
WorldManager * worldManager;
ParameterManager * parameterManager;

DiscreteToroid * world;
